Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetLocalIP ¶
func GetLocalIP() []string
Types ¶
type ErrorCounter ¶
func NewErrorCounter ¶
func NewErrorCounter(execInterval, clearInterval time.Duration) *ErrorCounter
func (*ErrorCounter) Incr ¶
func (ec *ErrorCounter) Incr(data uint64)
func (*ErrorCounter) RegisterCallback ¶
func (ec *ErrorCounter) RegisterCallback(name string, moreThen uint64, fn func(uint64))
func (*ErrorCounter) Run ¶
func (ec *ErrorCounter) Run()
func (*ErrorCounter) Stop ¶
func (ec *ErrorCounter) Stop()
func (*ErrorCounter) UnRegisterCallback ¶
func (ec *ErrorCounter) UnRegisterCallback(name string)
Directories
¶
| Path | Synopsis |
|---|---|
|
redis返回数据 Error: -Error message\r\n Simple String: +OK\r\n Integers: :1000\r\n(int64) Bulk Strings: $6\r\nfoobar\r\n $0\r\n\r\n $-1\r\n Arrays: *2\r\n$3\r\nfoo\r\n$3\r\nbar\r\n *0\r\n *-1\r\n A client sends to the Redis server a RESP Array consisting of just Bulk Strings.
|
redis返回数据 Error: -Error message\r\n Simple String: +OK\r\n Integers: :1000\r\n(int64) Bulk Strings: $6\r\nfoobar\r\n $0\r\n\r\n $-1\r\n Arrays: *2\r\n$3\r\nfoo\r\n$3\r\nbar\r\n *0\r\n *-1\r\n A client sends to the Redis server a RESP Array consisting of just Bulk Strings. |
Click to show internal directories.
Click to hide internal directories.